## Elements {docsify-ignore}

In this chapter we analyze the rules by which the components generate the `DOM elements`.

### MuuriComponent

The MuuriComponent generate a `div` element in wich the items are contained. You can interact with it using this [prop](muuricomponent/props?id=gridprops).

### Item

The Items must always consist of at least two elements:

  - The `outer element` *(used for positioning)*.
  - The `inner element` *(used for animating the item's visibility)*.

You can insert any markup you wish inside the inner item element.

```js
const Item = () => (
  <div className="item">
    <div className="item-content">
      {/* Safe zone, enter your custom markup */}
      This can be anything.
      {/* Safe zone ends */}
    </div>
  </div>
)
```

### CSS classes

Some specific `CSS classes` are added to the DOM elements of the components. <br>
One class is added in relation of the `type` and others class are added in relation to the (eventual) `event` which is interacting with the element. <br>
You can define these classes to manipulate the `style` of the DOM elements.

The CSS classes are the following:

```js
// Class names can be changed in the MuuriComponent props
{ 
  // The class of the element generated by the MuuriComponent
  containerClass: 'muuri',
  // The class of the (outer) element generated by the Item
  itemClass: 'muuri-item',
  // The class of the (outer) item element while it is showing
  itemVisibleClass: 'muuri-item-shown',
  // The class of the (outer) item element while it is showing
  itemHiddenClass: 'muuri-item-hidden',
  // The class of the (outer) item element while it is being positioned
  itemPositioningClass: 'muuri-item-positioning',
  // The class of the (outer) item element while it is being dragged
  itemDraggingClass: 'muuri-item-dragging',
  // The class of the (outer) item element while it is being released
  itemReleasingClass: 'muuri-item-releasing'
}
```